@@ -2,7 +2,7 @@
 
 use lexer::Lexer;
 use parser::{PResult, Parser, ParserConfig};
-use swc_common::{input::StringInput, SourceFile};
+use swc_common::{input::StringInput, BytePos, SourceFile};
 
 #[macro_use]
 mod macros;
@@ -25,6 +25,21 @@ where
     }
 }
 
+pub fn parse_str<'a, T>(
+    src: &'a str,
+    start_pos: BytePos,
+    end_pos: BytePos,
+    config: ParserConfig,
+) -> PResult<T>
+where
+    Parser<Lexer<StringInput<'a>>>: Parse<T>,
+{
+    let lexer = Lexer::new(StringInput::new(src, start_pos, end_pos));
+    let mut parser = Parser::new(lexer, config);
+
+    parser.parse()
+}
+
 pub fn parse_file<'a, T>(fm: &'a SourceFile, config: ParserConfig) -> PResult<T>
 where
     Parser<Lexer<StringInput<'a>>>: Parse<T>,
