@@ -77,7 +77,7 @@ where
             parse_selectors: true,
         })?;
 
-        let last = self.input.last_pos();
+        let last = self.input.last_pos()?;
 
         Ok(Stylesheet {
             span: Span::new(start.lo, last, Default::default()),
@@ -176,15 +176,14 @@ where
                 expect!(self, "(");
                 let value = self.parse_str()?.value;
                 expect!(self, ")");
-                Ok(Str { span, value })
+                Ok(Str {
+                    span: span!(self, span.lo),
+                    value,
+                })
             }
 
             Token::Url { .. } => match bump!(self) {
-                Token::Url { value } => {
-                    let span = self.input.cur_span()?;
-
-                    Ok(Str { span, value })
-                }
+                Token::Url { value } => Ok(Str { span, value }),
                 _ => {
                     unreachable!()
                 }
