@@ -3,7 +3,7 @@ use crate::{
     error::{Error, ErrorKind},
     Parse,
 };
-use swc_common::BytePos;
+use swc_common::{BytePos, Spanned};
 use swc_css_ast::*;
 
 #[cfg(test)]
@@ -16,16 +16,22 @@ where
     /// Ported from `parseDeclaration` of esbuild.
     ///
     /// https://github.com/evanw/esbuild/blob/a9456dfbf08ab50607952eefb85f2418968c124c/internal/css_parser/css_parser.go#L987
-    pub(super) fn parse_property_values(&mut self) -> PResult<Vec<Value>> {
+    ///
+    /// Returned [BytePos] is `hi`.
+    pub(super) fn parse_property_values(&mut self) -> PResult<(Vec<Value>, BytePos)> {
         let mut values = vec![];
         let mut state = self.input.state();
+
+        let mut hi = self.input.last_pos()?;
         loop {
             if is_one_of!(self, EOF, ";", "}", "!", ")") {
                 self.input.reset(&state);
                 break;
             }
 
-            values.push(self.parse_one_value()?);
+            let v = self.parse_one_value()?;
+            hi = v.span().hi;
+            values.push(v);
 
             state = self.input.state();
 
@@ -35,7 +41,7 @@ where
         }
 
         // TODO: Make this lazy
-        Ok(values)
+        Ok((values, hi))
     }
 
     fn parse_one_value(&mut self) -> PResult<Value> {
@@ -59,7 +65,7 @@ where
                 self.input.skip_ws()?;
             }
 
-            return Ok(Value::Values(Values {
+            return Ok(Value::Space(SpaceValues {
                 span: span!(self, span.lo),
                 values,
             }));
